@@ -67,5 +67,5 @@ class HonCommand:
     @property
     def settings(self):
         """Parameters with typology enum and range"""
-        return {s: self._parameters[s] for s in self.setting_keys}
+        return {s: self._parameters.get(s) for s in self.setting_keys if self._parameters.get(s) is not None}
 
